# `emblematic` [![Available on PyPI](https://img.shields.io/pypi/v/emblematic)](https://pypi.org/project/emblematic/)

Simple icon generator

\[ **[Documentation]** | **[PyPI]** | [Repository] \]

<!-- Add an image or some examples here, if available! -->


[Documentation]: https://emblematic.readthedocs.io/latest/
[PyPI]: https://pypi.org/project/emblematic
[Repository]: https://github.com/Steffo99/emblematic/
